==> exabel-data-sdk-3.3.0.tar.gz: exabel-data-sdk-3.3.0/exabel_data_sdk/tests/scripts/test_update_entity_type.py <==
import unittest
from unittest import mock

from google.protobuf.field_mask_pb2 import FieldMask

from exabel_data_sdk import ExabelClient
from exabel_data_sdk.client.api.data_classes.entity_type import EntityType
from exabel_data_sdk.scripts.update_entity_type import UpdateEntityType

common_args = [
    "script-name",
    "--api-key",
    "123",
    "--name",
    "entityTypes/acme.entity_type",
]


class TestUpdateEntityType(unittest.TestCase):
    def test_update_entity_type(self):
        args = common_args + [
            "--display-name",
            "The display name",
            "--description",
            "The description.",
            "--is-associative",
        ]
        script = UpdateEntityType(args, "Update an entity type.")
        mock_client = mock.create_autospec(ExabelClient(host="host", api_key="123"))
        script.run_script(mock_client, script.parse_arguments())
        mock_client.entity_api.update_entity_type.assert_called_once_with(
            entity_type=EntityType(
                name="entityTypes/acme.entity_type",
                display_name="The display name",
                description="The description.",
                is_associative=True,
            ),
            update_mask=FieldMask(paths=["display_name", "description", "is_associative"]),
        )

    def test_update_entity_type_display_name_only(self):
        args = common_args + [
            "--display-name",
            "The display name",
        ]
        script = UpdateEntityType(args, "Update an entity type.")
        mock_client = mock.create_autospec(ExabelClient(host="host", api_key="123"))
        script.run_script(mock_client, script.parse_arguments())
        mock_client.entity_api.update_entity_type.assert_called_once_with(
            entity_type=EntityType(
                name="entityTypes/acme.entity_type",
                display_name="The display name",
                description="",
                is_associative=None,
            ),
            update_mask=FieldMask(paths=["display_name"]),
        )

==> exabel-data-sdk-4.1.0.tar.gz: exabel-data-sdk-4.1.0/exabel_data_sdk/tests/scripts/test_update_entity_type.py <==
import unittest
from unittest import mock

from google.protobuf.field_mask_pb2 import FieldMask

from exabel_data_sdk import ExabelClient
from exabel_data_sdk.client.api.data_classes.entity_type import EntityType
from exabel_data_sdk.client.api.entity_api import EntityApi
from exabel_data_sdk.scripts.update_entity_type import UpdateEntityType

common_args = [
    "script-name",
    "--api-key",
    "123",
    "--name",
    "entityTypes/acme.entity_type",
]


class TestUpdateEntityType(unittest.TestCase):
    def setUp(self) -> None:
        self.client = mock.create_autospec(ExabelClient)
        self.client.entity_api = mock.create_autospec(EntityApi)

    def test_update_entity_type(self):
        args = common_args + [
            "--display-name",
            "The display name",
            "--description",
            "The description.",
            "--is-associative",
        ]
        script = UpdateEntityType(args, "Update an entity type.")
        script.run_script(self.client, script.parse_arguments())
        self.client.entity_api.update_entity_type.assert_called_once_with(
            entity_type=EntityType(
                name="entityTypes/acme.entity_type",
                display_name="The display name",
                description="The description.",
                is_associative=True,
            ),
            update_mask=FieldMask(paths=["display_name", "description", "is_associative"]),
        )

    def test_update_entity_type_display_name_only(self):
        args = common_args + [
            "--display-name",
            "The display name",
        ]
        script = UpdateEntityType(args, "Update an entity type.")
        script.run_script(self.client, script.parse_arguments())
        self.client.entity_api.update_entity_type.assert_called_once_with(
            entity_type=EntityType(
                name="entityTypes/acme.entity_type",
                display_name="The display name",
                description="",
                is_associative=None,
            ),
            update_mask=FieldMask(paths=["display_name"]),
        )
